Learn R Programming

india (version 0.1-2)

aircraft: Aircraft data

Description

This dataset is presented in Rousseeuw and Leroy (1987, pp. 154), and the aim is to model the cost of 23 single-engine aircraft (in unit of $100,000) as a function of the following explanatory variables: aspect ratio, lift-to-drag ratio, weight of the plane, in pounds, and maximal thrust.

Usage

data(aircraft)

Arguments

Format

A data frame with 23 observations on the following 5 variables.

aspect

aspect ratio.

lift2drag

lift-to-drag ratio.

weight

weight of the plane (in pounds).

thrust

maximal thrust.

cost

cost of 23 single-engine aircraft (in unit of $100,000).