This dataset is presented in Rousseeuw and Leroy (1987, pp. 154), and the aim is to model the cost of 23 single-engine aircraft (in unit of $100,000) as a function of the following explanatory variables: aspect ratio, lift-to-drag ratio, weight of the plane, in pounds, and maximal thrust.
data(aircraft)A data frame with 23 observations on the following 5 variables.
aspect ratio.
lift-to-drag ratio.
weight of the plane (in pounds).
maximal thrust.
cost of 23 single-engine aircraft (in unit of $100,000).